[Openmp-commits] [PATCH] D91478: [OpenMP] Fix building for windows after adding omp_calloc

Martin Storsjö via Phabricator via Openmp-commits openmp-commits at lists.llvm.org
Fri Nov 13 23:43:26 PST 2020


mstorsjo created this revision.
mstorsjo added reviewers: Nawrin, AndreyChurbanov, jdoerfert.
Herald added subscribers: guansong, yaxunl.
Herald added a project: OpenMP.
mstorsjo requested review of this revision.
Herald added a subscriber: sstefan1.

Repository:
  rG LLVM Github Monorepo

https://reviews.llvm.org/D91478

Files:
  openmp/runtime/tools/generate-def.pl


Index: openmp/runtime/tools/generate-def.pl
===================================================================
--- openmp/runtime/tools/generate-def.pl
+++ openmp/runtime/tools/generate-def.pl
@@ -108,8 +108,8 @@
     foreach my $entry ( keys( %$entries ) ) {
         if ( not $entries->{ $entry }->{ obsolete } ) {
             my $ordinal = $entries->{ $entry }->{ ordinal };
-            # omp_alloc and omp_free are C/C++ only functions, skip "1000+ordinal" for them
-            if ( $entry =~ m{\A[ok]mp_} and $entry ne "omp_alloc" and $entry ne "omp_free" ) {
+            # omp_alloc, omp_calloc and omp_free are C/C++ only functions, skip "1000+ordinal" for them
+            if ( $entry =~ m{\A[ok]mp_} and $entry ne "omp_alloc" and $entry ne "omp_calloc" and $entry ne "omp_free" ) {
                 if ( not defined( $ordinal ) ) {
                     runtime_error(
                         "Bad entry \"$entry\": ordinal number is not specified."


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D91478.305305.patch
Type: text/x-patch
Size: 965 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/openmp-commits/attachments/20201114/75ef440f/attachment.bin>


More information about the Openmp-commits mailing list